// Code generated by ent, DO NOT EDIT.

package ent

import (
	"context"
	"fmt"
	"log"

	"github.com/direktiv/direktiv/pkg/secrets/ent/migrate"

	"github.com/direktiv/direktiv/pkg/secrets/ent/namespacesecret"

	"entgo.io/ent/dialect"
	"entgo.io/ent/dialect/sql"
)

// Client is the client that holds all ent builders.
type Client struct {
	config
	// Schema is the client for creating, migrating and dropping schema.
	Schema *migrate.Schema
	// NamespaceSecret is the client for interacting with the NamespaceSecret builders.
	NamespaceSecret *NamespaceSecretClient
}

// NewClient creates a new client configured with the given options.
func NewClient(opts ...Option) *Client {
	cfg := config{log: log.Println, hooks: &hooks{}}
	cfg.options(opts...)
	client := &Client{config: cfg}
	client.init()
	return client
}

func (c *Client) init() {
	c.Schema = migrate.NewSchema(c.driver)
	c.NamespaceSecret = NewNamespaceSecretClient(c.config)
}

// Open opens a database/sql.DB specified by the driver name and
// the data source name, and returns a new client attached to it.
// Optional parameters can be added for configuring the client.
func Open(driverName, dataSourceName string, options ...Option) (*Client, error) {
	switch driverName {
	case dialect.MySQL, dialect.Postgres, dialect.SQLite:
		drv, err := sql.Open(driverName, dataSourceName)
		if err != nil {
			return nil, err
		}
		return NewClient(append(options, Driver(drv))...), nil
	default:
		return nil, fmt.Errorf("unsupported driver: %q", driverName)
	}
}

// Tx returns a new transactional client. The provided context
// is used until the transaction is committed or rolled back.
func (c *Client) Tx(ctx context.Context) (*Tx, error) {
	if _, ok := c.driver.(*txDriver); ok {
		return nil, fmt.Errorf("ent: cannot start a transaction within a transaction")
	}
	tx, err := newTx(ctx, c.driver)
	if err != nil {
		return nil, fmt.Errorf("ent: starting a transaction: %w", err)
	}
	cfg := c.config
	cfg.driver = tx
	return &Tx{
		ctx:             ctx,
		config:          cfg,
		NamespaceSecret: NewNamespaceSecretClient(cfg),
	}, nil
}

// BeginTx returns a transactional client with specified options.
func (c *Client) BeginTx(ctx context.Context, opts *sql.TxOptions) (*Tx, error) {
	if _, ok := c.driver.(*txDriver); ok {
		return nil, fmt.Errorf("ent: cannot start a transaction within a transaction")
	}
	tx, err := c.driver.(interface {
		BeginTx(context.Context, *sql.TxOptions) (dialect.Tx, error)
	}).BeginTx(ctx, opts)
	if err != nil {
		return nil, fmt.Errorf("ent: starting a transaction: %w", err)
	}
	cfg := c.config
	cfg.driver = &txDriver{tx: tx, drv: c.driver}
	return &Tx{
		ctx:             ctx,
		config:          cfg,
		NamespaceSecret: NewNamespaceSecretClient(cfg),
	}, nil
}

// Debug returns a new debug-client. It's used to get verbose logging on specific operations.
//
//	client.Debug().
//		NamespaceSecret.
//		Query().
//		Count(ctx)
//
func (c *Client) Debug() *Client {
	if c.debug {
		return c
	}
	cfg := c.config
	cfg.driver = dialect.Debug(c.driver, c.log)
	client := &Client{config: cfg}
	client.init()
	return client
}

// Close closes the database connection and prevents new queries from starting.
func (c *Client) Close() error {
	return c.driver.Close()
}

// Use adds the mutation hooks to all the entity clients.
// In order to add hooks to a specific client, call: `client.Node.Use(...)`.
func (c *Client) Use(hooks ...Hook) {
	c.NamespaceSecret.Use(hooks...)
}

// NamespaceSecretClient is a client for the NamespaceSecret schema.
type NamespaceSecretClient struct {
	config
}

// NewNamespaceSecretClient returns a client for the NamespaceSecret from the given config.
func NewNamespaceSecretClient(c config) *NamespaceSecretClient {
	return &NamespaceSecretClient{config: c}
}

// Use adds a list of mutation hooks to the hooks stack.
// A call to `Use(f, g, h)` equals to `namespacesecret.Hooks(f(g(h())))`.
func (c *NamespaceSecretClient) Use(hooks ...Hook) {
	c.hooks.NamespaceSecret = append(c.hooks.NamespaceSecret, hooks...)
}

// Create returns a builder for creating a NamespaceSecret entity.
func (c *NamespaceSecretClient) Create() *NamespaceSecretCreate {
	mutation := newNamespaceSecretMutation(c.config, OpCreate)
	return &NamespaceSecretCreate{config: c.config, hooks: c.Hooks(), mutation: mutation}
}

// CreateBulk returns a builder for creating a bulk of NamespaceSecret entities.
func (c *NamespaceSecretClient) CreateBulk(builders ...*NamespaceSecretCreate) *NamespaceSecretCreateBulk {
	return &NamespaceSecretCreateBulk{config: c.config, builders: builders}
}

// Update returns an update builder for NamespaceSecret.
func (c *NamespaceSecretClient) Update() *NamespaceSecretUpdate {
	mutation := newNamespaceSecretMutation(c.config, OpUpdate)
	return &NamespaceSecretUpdate{config: c.config, hooks: c.Hooks(), mutation: mutation}
}

// UpdateOne returns an update builder for the given entity.
func (c *NamespaceSecretClient) UpdateOne(ns *NamespaceSecret) *NamespaceSecretUpdateOne {
	mutation := newNamespaceSecretMutation(c.config, OpUpdateOne, withNamespaceSecret(ns))
	return &NamespaceSecretUpdateOne{config: c.config, hooks: c.Hooks(), mutation: mutation}
}

// UpdateOneID returns an update builder for the given id.
func (c *NamespaceSecretClient) UpdateOneID(id int) *NamespaceSecretUpdateOne {
	mutation := newNamespaceSecretMutation(c.config, OpUpdateOne, withNamespaceSecretID(id))
	return &NamespaceSecretUpdateOne{config: c.config, hooks: c.Hooks(), mutation: mutation}
}

// Delete returns a delete builder for NamespaceSecret.
func (c *NamespaceSecretClient) Delete() *NamespaceSecretDelete {
	mutation := newNamespaceSecretMutation(c.config, OpDelete)
	return &NamespaceSecretDelete{config: c.config, hooks: c.Hooks(), mutation: mutation}
}

// DeleteOne returns a builder for deleting the given entity.
func (c *NamespaceSecretClient) DeleteOne(ns *NamespaceSecret) *NamespaceSecretDeleteOne {
	return c.DeleteOneID(ns.ID)
}

// DeleteOne returns a builder for deleting the given entity by its id.
func (c *NamespaceSecretClient) DeleteOneID(id int) *NamespaceSecretDeleteOne {
	builder := c.Delete().Where(namespacesecret.ID(id))
	builder.mutation.id = &id
	builder.mutation.op = OpDeleteOne
	return &NamespaceSecretDeleteOne{builder}
}

// Query returns a query builder for NamespaceSecret.
func (c *NamespaceSecretClient) Query() *NamespaceSecretQuery {
	return &NamespaceSecretQuery{
		config: c.config,
	}
}

// Get returns a NamespaceSecret entity by its id.
func (c *NamespaceSecretClient) Get(ctx context.Context, id int) (*NamespaceSecret, error) {
	return c.Query().Where(namespacesecret.ID(id)).Only(ctx)
}

// GetX is like Get, but panics if an error occurs.
func (c *NamespaceSecretClient) GetX(ctx context.Context, id int) *NamespaceSecret {
	obj, err := c.Get(ctx, id)
	if err != nil {
		panic(err)
	}
	return obj
}

// Hooks returns the client hooks.
func (c *NamespaceSecretClient) Hooks() []Hook {
	return c.hooks.NamespaceSecret
}
